==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/BinaryBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class BinaryBuildSourceBuilder extends BinaryBuildSourceFluentImpl<BinaryBuildSourceBuilder> implements VisitableBuilder<BinaryBuildSource,BinaryBuildSourceBuilder>{

    BinaryBuildSourceFluent<?> fluent;
    Boolean validationEnabled;

    public BinaryBuildSourceBuilder(){
            this(true);
    }
    public BinaryBuildSourceBuilder(Boolean validationEnabled){
            this(new BinaryBuildSource(), validationEnabled);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent){
            this(fluent, true);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new BinaryBuildSource(), validationEnabled);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent,BinaryBuildSource instance){
            this(fluent, instance, true);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent,BinaryBuildSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAsFile(instance.getAsFile()); 
            this.validationEnabled = validationEnabled; 
    }
    public BinaryBuildSourceBuilder(BinaryBuildSource instance){
            this(instance,true);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAsFile(instance.getAsFile()); 
            this.validationEnabled = validationEnabled; 
    }

    public BinaryBuildSource build(){
            BinaryBuildSource buildable = new BinaryBuildSource(fluent.getAsFile());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            BinaryBuildSourceBuilder that = (BinaryBuildSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/BinaryBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class BinaryBuildSourceBuilder extends BinaryBuildSourceFluentImpl<BinaryBuildSourceBuilder> implements VisitableBuilder<BinaryBuildSource,BinaryBuildSourceBuilder>{

    BinaryBuildSourceFluent<?> fluent;
    Boolean validationEnabled;

    public BinaryBuildSourceBuilder(){
            this(true);
    }
    public BinaryBuildSourceBuilder(Boolean validationEnabled){
            this(new BinaryBuildSource(), validationEnabled);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent){
            this(fluent, true);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new BinaryBuildSource(), validationEnabled);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent,BinaryBuildSource instance){
            this(fluent, instance, true);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSourceFluent<?> fluent,BinaryBuildSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAsFile(instance.getAsFile()); 
            this.validationEnabled = validationEnabled; 
    }
    public BinaryBuildSourceBuilder(BinaryBuildSource instance){
            this(instance,true);
    }
    public BinaryBuildSourceBuilder(BinaryBuildSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAsFile(instance.getAsFile()); 
            this.validationEnabled = validationEnabled; 
    }

    public BinaryBuildSource build(){
            BinaryBuildSource buildable = new BinaryBuildSource(fluent.getAsFile());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            BinaryBuildSourceBuilder that = (BinaryBuildSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
